## Font View

Font View provides an overview of all glyphs of a font.
It is displayed when a new Glyphs file is created.
If multiple tabs are open, jump to Font View by clicking the leftmost tab or pressing Cmd-Opt-1.